@@ -59,11 +59,15 @@ class HamsterApplet(object):
         self.applet = applet
         self.applet.set_applet_flags (gnomeapplet.EXPAND_MINOR);
 
+        self.preferences_editor = None
+        self.applet.about = None
+
         self.button = PanelButton()
         
         # load window of activity switcher and todays view
         self.glade = gtk.glade.XML(os.path.join(SHARED_DATA_DIR, "menu.glade"))
         self.window = self.glade.get_widget('hamster-window')
+        self.window.set_keep_above(True)
         
         # set up drop down menu
         self.activity_list = self.glade.get_widget('activity-list')
@@ -291,6 +295,11 @@ class HamsterApplet(object):
         else:
             self.activity_list.child.set_text('')
 
+        # doing unstick / stick here, because sometimes while switching
+        # between workplaces window still manages to dissappear
+        self.window.unstick()
+        self.window.stick() #show on all desktops
+
         gobject.idle_add(self._delayed_display)  
         
     def _delayed_display(self):
@@ -367,15 +376,22 @@ class HamsterApplet(object):
         custom_fact.show()
 
     def on_about (self, component, verb):
-        from hamster.about import show_about
-        show_about(self.applet)
+        if self.applet.about:
+            self.applet.about.present()
+        else:
+            from hamster.about import show_about
+            show_about(self.applet)
 
     def show_preferences(self, menu_item, verb):
         from hamster.preferences import PreferencesEditor
 
         dispatcher.dispatch('panel_visible', False)
-        activities_editor = PreferencesEditor()
-        activities_editor.show()
+        
+        if self.preferences_editor and self.preferences_editor.window:
+            self.preferences_editor.window.present()
+        else:
+            self.preferences_editor = PreferencesEditor()
+            self.preferences_editor.show()
     
     """signals"""
     def after_activity_update(self, widget, renames):
